@@ -19,6 +19,7 @@ $Id: __init__.py 86232 2008-05-03 15:09:33Z ctheune $
 import subprocess
 
 import cStringIO
+import errno
 import gc
 import Queue
 import re
@@ -45,6 +46,7 @@ import zope.testing.testrunner.process
 import zope.testing.testrunner.interfaces
 import zope.testing.testrunner.debug
 import zope.testing.testrunner.tb_format
+import zope.testing.testrunner.shuffle
 
 
 PYREFCOUNT_PATTERN = re.compile('\[[0-9]+ refs\]')
@@ -187,6 +189,7 @@ class Runner(object):
                 zope.testing.testrunner.garbagecollection.Debug(self))
 
         self.features.append(zope.testing.testrunner.find.Find(self))
+        self.features.append(zope.testing.testrunner.shuffle.Shuffle(self))
         self.features.append(zope.testing.testrunner.process.SubProcess(self))
         self.features.append(zope.testing.testrunner.filter.Filter(self))
         self.features.append(zope.testing.testrunner.listing.Listing(self))
@@ -383,6 +386,8 @@ class SetUpLayerFailure(unittest.TestCase):
 def spawn_layer_in_subprocess(result, script_parts, options, features,
                               layer_name, layer, failures, errors,
                               resume_number):
+    output = options.output
+
     try:
         # BBB
         if script_parts is None:
@@ -448,9 +453,7 @@ def spawn_layer_in_subprocess(result, script_parts, options, features,
             else:
                 break
         else:
-            output = options.output
-            output.error_with_banner("Could not communicate with subprocess:\n"
-                                     "\n" + suberr)
+            output.error_with_banner("Could not communicate with subprocess")
 
         while nfail > 0:
             nfail -= 1
