@@ -13,13 +13,12 @@
 ##############################################################################
 """Tests for the testing framework.
 
-$Id: tests.py 90401 2008-08-27 07:41:00Z srichter $
+$Id: tests.py 104880 2009-10-07 17:53:44Z sidnei $
 """
 
-import os
-import sys
+import re
 import unittest
-from zope.testing import doctest, testrunner
+from zope.testing import doctest, renormalizing
 
 def test_suite():
     return unittest.TestSuite((
@@ -28,6 +27,15 @@ def test_suite():
         doctest.DocTestSuite('zope.testing.server'),
         doctest.DocFileSuite('doctest.txt'),
         doctest.DocFileSuite('formparser.txt'),
-        doctest.DocFileSuite('module.txt'),
+        doctest.DocFileSuite(
+            'module.txt',
+            # when this test is run in isolation, the error message shows the
+            # module name as fully qualified; when it is run as part of the
+            # full test suite, the error message shows the module name as
+            # relative.
+            checker=renormalizing.RENormalizing([
+                (re.compile('No module named zope.testing.unlikelymodulename'),
+                 'No module named unlikelymodulename')])),
         doctest.DocFileSuite('setupstack.txt'),
+        doctest.DocTestSuite(doctest, optionflags=doctest.INTERPRET_FOOTNOTES),
         ))
